@@ -29,7 +29,8 @@ class NodeGroupTemplateManager(base.ResourceManager):
                       node_configs=None, floating_ip_pool=None,
                       security_groups=None, auto_security_group=None,
                       availability_zone=None, volumes_availability_zone=None,
-                      volume_type=None, image_id=None, is_proxy_gateway=None):
+                      volume_type=None, image_id=None, is_proxy_gateway=None,
+                      volume_local_to_instance=None):
 
         data = {
             'name': name,
@@ -58,6 +59,9 @@ class NodeGroupTemplateManager(base.ResourceManager):
                              volumes_availability_zone})
             if volume_type:
                 data.update({"volume_type": volume_type})
+            if volume_local_to_instance:
+                data.update(
+                    {"volume_local_to_instance": volume_local_to_instance})
 
         return data
 
@@ -66,7 +70,8 @@ class NodeGroupTemplateManager(base.ResourceManager):
                node_processes=None, node_configs=None, floating_ip_pool=None,
                security_groups=None, auto_security_group=None,
                availability_zone=None, volumes_availability_zone=None,
-               volume_type=None, image_id=None, is_proxy_gateway=None):
+               volume_type=None, image_id=None, is_proxy_gateway=None,
+               volume_local_to_instance=None):
 
         data = self._assign_field(name, plugin_name, hadoop_version, flavor_id,
                                   description, volumes_per_node, volumes_size,
@@ -74,7 +79,8 @@ class NodeGroupTemplateManager(base.ResourceManager):
                                   floating_ip_pool, security_groups,
                                   auto_security_group, availability_zone,
                                   volumes_availability_zone, volume_type,
-                                  image_id, is_proxy_gateway)
+                                  image_id, is_proxy_gateway,
+                                  volume_local_to_instance)
 
         return self._create('/node-group-templates', data,
                             'node_group_template')
@@ -85,7 +91,8 @@ class NodeGroupTemplateManager(base.ResourceManager):
                floating_ip_pool=None, security_groups=None,
                auto_security_group=None, availability_zone=None,
                volumes_availability_zone=None, volume_type=None,
-               image_id=None, is_proxy_gateway=None):
+               image_id=None, is_proxy_gateway=None,
+               volume_local_to_instance=None):
 
         data = self._assign_field(name, plugin_name, hadoop_version, flavor_id,
                                   description, volumes_per_node, volumes_size,
@@ -93,7 +100,8 @@ class NodeGroupTemplateManager(base.ResourceManager):
                                   floating_ip_pool, security_groups,
                                   auto_security_group, availability_zone,
                                   volumes_availability_zone, volume_type,
-                                  image_id, is_proxy_gateway)
+                                  image_id, is_proxy_gateway,
+                                  volume_local_to_instance)
 
         return self._update('/node-group-templates/%s' % ng_template_id, data,
                             'node_group_template')
